==> kdepim-addons-17.07.90.tar.xz: kdepim-addons-17.07.90/kaddressbook/importexportplugins/csv/csvimportexportplugin.cpp <==
/*
   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "csvimportexportplugin.h"
#include "csvimportexportplugininterface.h"
#include <kpluginfactory.h>

K_PLUGIN_FACTORY_WITH_JSON(CSVImportExportPluginFactory, "kaddressbook_importexportcsvplugin.json", registerPlugin<CSVImportExportPlugin>();
                           )

CSVImportExportPlugin::CSVImportExportPlugin(QObject *parent, const QList<QVariant> &)
    : KAddressBookImportExport::KAddressBookImportExportPlugin(parent)
{
}

CSVImportExportPlugin::~CSVImportExportPlugin()
{
}

PimCommon::AbstractGenericPluginInterface *CSVImportExportPlugin::createInterface(KActionCollection *ac, QObject *parent)
{
    CSVImportExportPluginInterface *interface = new CSVImportExportPluginInterface(parent);
    interface->createAction(ac);
    return interface;
}

bool CSVImportExportPlugin::hasPopupMenuSupport() const
{
    return true;
}

#include "csvimportexportplugin.moc"

==> kdepim-addons-18.04.0.tar.xz: kdepim-addons-18.04.0/kaddressbook/importexportplugins/csv/csvimportexportplugin.cpp <==
/*
   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "csvimportexportplugin.h"
#include "csvimportexportplugininterface.h"
#include <kpluginfactory.h>

K_PLUGIN_CLASS_WITH_JSON(CSVImportExportPlugin, "kaddressbook_importexportcsvplugin.json")

CSVImportExportPlugin::CSVImportExportPlugin(QObject *parent, const QList<QVariant> &)
    : KAddressBookImportExport::KAddressBookImportExportPlugin(parent)
{
}

CSVImportExportPlugin::~CSVImportExportPlugin()
{
}

PimCommon::AbstractGenericPluginInterface *CSVImportExportPlugin::createInterface(KActionCollection *ac, QObject *parent)
{
    CSVImportExportPluginInterface *interface = new CSVImportExportPluginInterface(parent);
    interface->createAction(ac);
    return interface;
}

bool CSVImportExportPlugin::hasPopupMenuSupport() const
{
    return true;
}

#include "csvimportexportplugin.moc"
